@@ -55,3 +55,30 @@ class CacheConfig(ConfigBase):
 @dataclass
 class AnalysisRobotConfig(ConfigBase):
     global_library_search_order: List[str] = field(default_factory=list)
+    # Timeout in seconds for loading libraries and variable files during analysis. If None, fallback to env var
+    # ROBOTCODE_LOAD_LIBRARY_TIMEOUT or default (10).
+    load_library_timeout: Optional[int] = None
+
+
+@config_section("robotcode.analysis.diagnosticModifiers")
+@dataclass
+class AnalysisDiagnosticModifiersConfig(ConfigBase):
+    ignore: List[str] = field(default_factory=list)
+    error: List[str] = field(default_factory=list)
+    warning: List[str] = field(default_factory=list)
+    information: List[str] = field(default_factory=list)
+    hint: List[str] = field(default_factory=list)
+
+
+@config_section("robotcode.workspace")
+@dataclass
+class WorkspaceConfig(ConfigBase):
+    exclude_patterns: List[str] = field(default_factory=list)
+
+
+@dataclass
+class WorkspaceAnalysisConfig:
+    exclude_patterns: List[str] = field(default_factory=list)
+    cache: CacheConfig = field(default_factory=CacheConfig)
+    robot: AnalysisRobotConfig = field(default_factory=AnalysisRobotConfig)
+    modifiers: AnalysisDiagnosticModifiersConfig = field(default_factory=AnalysisDiagnosticModifiersConfig)
